@@ -13,7 +13,7 @@ use Carp;
 use Exporter qw{ import };
 use File::Spec;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our @EXPORT_OK = qw{
     symlink_r
@@ -112,7 +112,8 @@ L<https://www.reddit.com/r/perl/comments/fluxay/can_i_make_relative_symbolic_lin
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-File-Symlink-Relative/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -120,7 +121,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2020 by Thomas R. Wyant, III
+Copyright (C) 2020-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
